@@ -24,9 +24,49 @@ var Evo = {
 	hasSelection : false,
 	blockquoteStyle : "margin:0 0 0 .8ex; border-left:2px #729fcf solid;padding-left:1ex",
 	magicSpacebarState: -1,
-	markCitationColor : null
+	markCitationColor : null,
+	plugins : null
 };
 
+Evo.RegisterPlugin = function(plugin)
+{
+	if (plugin == null)
+		return;
+
+	if (plugin.name === undefined) {
+		console.error("Evo.RegisterPlugin: Plugin '" + plugin + "' has missing 'name' member");
+		return;
+	}
+
+	if (plugin.setup === undefined) {
+		console.error("Evo.RegisterPlugin: Plugin '" + plugin.name + "' has missing 'setup' function");
+		return;
+	}
+
+	if (Evo.plugins == null)
+		Evo.plugins = [];
+
+	Evo.plugins.push(plugin);
+}
+
+Evo.setupPlugins = function(doc)
+{
+	if (Evo.plugins == null)
+		return;
+
+	var ii;
+
+	for (ii = 0; ii < Evo.plugins.length; ii++) {
+		try {
+			if (Evo.plugins[ii] != null)
+				Evo.plugins[ii].setup(doc);
+		} catch (err) {
+			console.error("Failed to setup plugin '" + Evo.plugins[ii].name + "': " + err.name + ": " + err.message);
+			Evo.plugins[ii] = null;
+		}
+	}
+}
+
 /* The 'traversar_obj' is an object, which implements a callback function:
    boolean exec(doc, iframe_id, level);
    and it returns whether continue the traversar */
@@ -619,6 +659,8 @@ Evo.initialize = function(elem)
 	} else
 		doc = document;
 
+	Evo.setupPlugins(doc);
+
 	elems = doc.getElementsByTagName("iframe");
 
 	for (ii = 0; ii < elems.length; ii++) {
@@ -628,6 +670,24 @@ Evo.initialize = function(elem)
 
 		if (iframe.contentDocument && iframe.contentDocument.body && iframe.contentDocument.body.childElementCount > 0)
 			Evo.initializeAndPostContentLoaded(iframe);
+		else if (iframe.contentDocument && iframe.contentDocument.body)
+			iframe.contentDocument.body.onload = function() { Evo.initializeAndPostContentLoaded(this); };
+	}
+
+	/* Ensure selection, used for the caret mode */
+	if (!doc.getSelection().anchorNode && doc.body.firstChild) {
+		if (doc.body) {
+			doc.getSelection().setPosition(doc.body.firstChild, 0);
+		}
+
+		if (doc.defaultView && !doc.defaultView.frameElement) {
+			var iframe = doc.getElementsByTagName('IFRAME')[0];
+
+			if (iframe && iframe.contentDocument && iframe.contentDocument.body && iframe.contentDocument.body.firstChild) {
+				iframe.focus();
+				iframe.contentDocument.getSelection().setPosition(iframe.contentDocument.body.firstChild, 0);
+			}
+		}
 	}
 
 	if (doc.defaultView && !doc.defaultView.frameElement && !doc.body.hasAttribute("class"))
@@ -671,12 +731,32 @@ Evo.initializeAndPostContentLoaded = function(elem)
 		iframe_id = window.frameElement.id;
 
 	Evo.initialize(elem);
-	window.webkit.messageHandlers.contentLoaded.postMessage(iframe_id);
+
+	/* Skip, when its content is not loaded yet */
+	if (iframe_id != "" && elem && elem.tagName == "IFRAME" && elem.contentDocument &&
+	    (!elem.contentDocument.body || !elem.contentDocument.body.childElementCount)) {
+		if (elem.contentDocument.body) {
+			elem.contentDocument.body.onload = function() { Evo.initializeAndPostContentLoaded(this); };
+		}
+	} else {
+		window.webkit.messageHandlers.contentLoaded.postMessage(iframe_id);
+	}
 
 	if (window.webkit.messageHandlers.mailDisplayMagicSpacebarStateChanged)
 		Evo.mailDisplayUpdateMagicSpacebarState();
 
 	Evo.AddTooltipToLinks(iframe_id);
+
+	var traversar = {
+		exec : function(doc, ifrm_id, level) {
+			if (doc.body && doc.body.firstElementChild) {
+				window.webkit.messageHandlers.contentLoaded.postMessage(ifrm_id);
+			}
+			return true;
+		}
+	};
+
+	Evo.foreachIFrameDocument(document, traversar, false, 0);
 }
 
 Evo.EnsureMainDocumentInitialized = function()
