@@ -47,7 +47,7 @@ is_past_event (ECalComponent *comp)
 	if (!comp)
 		return TRUE;
 
-	end_date = e_cal_component_get_dtend (comp);
+	end_date = e_cal_component_get_vtype (comp) == E_CAL_COMPONENT_EVENT ? e_cal_component_get_dtend (comp) : NULL;
 
 	if (!end_date)
 		return FALSE;
@@ -958,17 +958,15 @@ e_cal_dialogs_recur_icalcomp (ECalClient *client,
 
 	g_return_val_if_fail (icomp != NULL, FALSE);
 
+	if (!e_cal_util_component_is_instance (icomp)) {
+		*mod = E_CAL_OBJ_MOD_ALL;
+		return TRUE;
+	}
+
 	comp = e_cal_component_new_from_icalcomponent (i_cal_component_clone (icomp));
 	if (!comp)
 		return FALSE;
 
-	if (!e_cal_component_is_instance (comp)) {
-		*mod = E_CAL_OBJ_MOD_ALL;
-		g_object_unref (comp);
-
-		return TRUE;
-	}
-
 	res = e_cal_dialogs_recur_component (client, comp, mod, parent, delegated);
 
 	g_object_unref (comp);
