@@ -180,6 +180,26 @@ action_context_delete_table_cb (GtkAction *action,
 	e_content_editor_delete_table (cnt_editor);
 }
 
+static void
+action_context_delete_hrule_cb (GtkAction *action,
+				EHTMLEditor *editor)
+{
+	EContentEditor *cnt_editor;
+
+	cnt_editor = e_html_editor_get_content_editor (editor);
+	e_content_editor_delete_h_rule (cnt_editor);
+}
+
+static void
+action_context_delete_image_cb (GtkAction *action,
+				EHTMLEditor *editor)
+{
+	EContentEditor *cnt_editor;
+
+	cnt_editor = e_html_editor_get_content_editor (editor);
+	e_content_editor_delete_image (cnt_editor);
+}
+
 static void
 action_context_insert_column_after_cb (GtkAction *action,
                                        EHTMLEditor *editor)
@@ -585,12 +605,14 @@ action_language_cb (GtkToggleAction *toggle_action,
 static gboolean
 update_mode_combobox (gpointer data)
 {
-	EHTMLEditor *editor = data;
+	GWeakRef *weak_ref = data;
+	EHTMLEditor *editor;
 	EContentEditor *cnt_editor;
 	GtkAction *action;
 	gboolean is_html;
 
-	if (!E_IS_HTML_EDITOR (editor))
+	editor = g_weak_ref_get (weak_ref);
+	if (!editor)
 		return FALSE;
 
 	cnt_editor = e_html_editor_get_content_editor (editor);
@@ -601,6 +623,8 @@ update_mode_combobox (gpointer data)
 	gtk_radio_action_set_current_value (
 		GTK_RADIO_ACTION (action), (is_html ? 1 : 0));
 
+	g_object_unref (editor);
+
 	return FALSE;
 }
 
@@ -622,7 +646,7 @@ html_editor_actions_notify_html_mode_cb (EContentEditor *cnt_editor,
 
 	/* This must be done from idle callback, because apparently we can change
 	 * current value in callback of current value change */
-	g_idle_add (update_mode_combobox, editor);
+	g_idle_add_full (G_PRIORITY_HIGH_IDLE, update_mode_combobox, e_weak_ref_new (editor), (GDestroyNotify) e_weak_ref_free);
 
 	action_group = editor->priv->html_actions;
 	gtk_action_group_set_visible (action_group, is_html);
@@ -1691,6 +1715,20 @@ static GtkActionEntry context_entries[] = {
 
 static GtkActionEntry html_context_entries[] = {
 
+	{ "context-delete-hrule",
+	  NULL,
+	  N_("Delete Rule"),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (action_context_delete_hrule_cb) },
+
+	{ "context-delete-image",
+	  NULL,
+	  N_("Delete Image"),
+	  NULL,
+	  NULL,
+	  G_CALLBACK (action_context_delete_image_cb) },
+
 	{ "context-insert-column-after",
 	  NULL,
 	  N_("Column After"),
