@@ -1055,13 +1055,7 @@ static void
 action_mail_folder_rename_cb (GtkAction *action,
                               EMailShellView *mail_shell_view)
 {
-	EMailShellSidebar *mail_shell_sidebar;
-	EMFolderTree *folder_tree;
-
-	mail_shell_sidebar = mail_shell_view->priv->mail_shell_sidebar;
-	folder_tree = e_mail_shell_sidebar_get_folder_tree (mail_shell_sidebar);
-
-	em_folder_tree_edit_selected (folder_tree);
+	e_mail_shell_view_rename_folder (mail_shell_view);
 }
 
 static void
@@ -1772,14 +1766,14 @@ static GtkActionEntry mail_entries[] = {
 	  NULL },
 
 	{ "mail-smart-backward",
-	  NULL,
+	  "go-up", /* In case a user adds it to the UI */
 	  NULL,  /* No menu item; key press only */
 	  "BackSpace",
 	  NULL,
 	  G_CALLBACK (action_mail_smart_backward_cb) },
 
 	{ "mail-smart-forward",
-	  NULL,
+	  "go-down", /* In case a user adds it to the UI */
 	  NULL,  /* No menu item; key press only */
 	  "space",
 	  NULL,
